import pychromecast
import requests


class Chromecast:
    def __init__(self, cast):
        self.cast = cast
        self.mc = cast.media_controller
        self.friendly_name = cast.device.friendly_name
        print("instance", self.cast)

    def quit_app(self):
        self.cast.quit_app()

    def status(self):
        _status = self.cast.status
        _mc = self.cast.media_controller

        return {
            'is_active_input': _status.is_active_input,
            'volume_level': _status.volume_level,
            'volume_muted': _status.volume_muted,
            'title': _mc.title,
            'duration': _mc.duration,
        }

    def increase_volume(self):
        return self.cast.volume_up()

    def decrease_volume(self):
        return self.cast.volume_down()

    def mute(self):
        self.cast.set_volume_muted(True)

    def unmute(self):
        self.cast.set_volume_muted(False)

    def play(self, url, content_type=None):
        if not content_type:
            content_type = requests.head(url).headers['content-type']
        self.mc.play_media(url, content_type)

    def partial_seek(self, delta):
        self.seek(self.mc.status.adjusted_current_time + delta)

    def seek(self, pos):
        self.mc.seek(pos)

    def stop(self):
        self.mc.stop()

    def pause(self):
        if self.mc.is_paused:
            self.mc.play()
        else:
            self.mc.pause()


def get_chromecasts():
    return {
        str(cast.uuid): Chromecast(cast)
        for cast in pychromecast.get_chromecasts()}



import sys
import time
import socket
import tty
import termios
from threading import Thread

from bottle import get, static_file, run
from .devices import get_devices


def get_ch():
        fd = sys.stdin.fileno()
        old_settings = termios.tcgetattr(fd)
        try:
            tty.setraw(sys.stdin.fileno())
            ch = sys.stdin.read(1)
        finally:
            termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
        return ch


@get('/movie')
def movie():
    return static_file(sys.argv[1], './')


def run_server():
    run(host="0.0.0.0", port=2015)


def start():
    ip = socket.gethostbyname(socket.gethostname())
    t = Thread(target=run_server)
    t.daemon = True
    t.start()
    print("waiting for discover chromecast")
    devices = get_devices()
    # take first device
    device = devices[next(devices.__iter__())]
    print("discovered", device.friendly_name)
    if not device.cast.is_idle:
        device.quit_app()
        print("kicked")
        time.sleep(5)
    device.play("http://%s:2015/movie" % ip)
    device.mc.block_until_active()

    while True:
        letter = get_ch()

        if letter in [' ', 'p']:
            device.pause()
            print("pause")

        elif letter in ['d']:
            print("%.2f / %.2f" % (
                device.cast.media_controller.status.adjusted_current_time,
                device.cast.media_controller.status.duration))

        elif letter in ['+', '=']:
            print("increase volume")
            device.increase_volume()

        elif letter in ['-']:
            print("decrease volume")
            device.decrease_volume()

        elif letter in ['n']:
            print("seek -30")
            device.partial_seek(-30)

        elif letter in ['m']:
            print("seek 30")
            device.partial_seek(30)

        elif letter in ['j']:
            print("seek -600")
            device.partial_seek(-600)

        elif letter in ['k']:
            print("seek 600")
            device.partial_seek(600)

        elif letter in ['x']:
            device.quit_app()
            print("close")
            exit()
        else:
            print("press x to exit")


if __name__ == "__main__":
    start()



from functools import lru_cache
from .chromecast import get_chromecasts


@lru_cache()
def get_devices():
    devices = {}
    for obtain_devices in [get_chromecasts]:
        devices.update(obtain_devices())
    return devices



#!/usr/bin/env python

from setuptools import setup, find_packages

print(find_packages())
setup(
    name='fstotv',
    version='1.0.2',
    description='send video in local to chromecast',
    author='Alberto Galera Jimenez',
    author_email='galerajimenez@gmail.com',
    url='https://github.com/agalera/fstotv',
    packages=find_packages(),
    # py_modules=['fstotv'],
    install_requires=['pychromecast', 'bottle'],
    entry_points={
        'console_scripts': ['fstotv = fstotv:start']
        },
    )
